@@ -12,7 +12,7 @@ use warnings;
 
 package Dist::Zilla::Plugin::Git::CommitBuild;
 BEGIN {
-  $Dist::Zilla::Plugin::Git::CommitBuild::VERSION = '1.101230';
+  $Dist::Zilla::Plugin::Git::CommitBuild::VERSION = '1.101270';
 }
 # ABSTRACT: checkin build results on separate branch
 
@@ -57,17 +57,22 @@ sub after_build {
 
 	my $exists = eval { $src->rev_parse( '--verify', '-q', $target_branch ); 1; };
 
-	my $build = Git::Wrapper->new( $args->{build_root} );
-	$build->init('-q');
-	$build->remote('add','src',$src_dir);
-	$build->fetch(qw(-q src));
-	if($exists){
-		$build->reset('--soft', "src/$target_branch");
+	eval {
+		my $build = Git::Wrapper->new( $args->{build_root} );
+		$build->init('-q');
+		$build->remote('add','src',$src_dir);
+		$build->fetch(qw(-q src));
+		if($exists){
+			$build->reset('--soft', "src/$target_branch");
+		}
+		$build->add('.');
+		$build->commit('-a', -m => _format_message($self->message, $src));
+		$build->checkout('-b',$target_branch);
+		$build->push('src', $target_branch);
+	};
+	if (my $e = $@) {
+		$self->log_fatal("failed to commit build: $e");
 	}
-	$build->add('.');
-	$build->commit('-a', -m => _format_message($self->message, $src));
-	$build->checkout('-b',$target_branch);
-	$build->push('src', $target_branch);
 }
 
 1;
@@ -81,7 +86,7 @@ Dist::Zilla::Plugin::Git::CommitBuild - checkin build results on separate branch
 
 =head1 VERSION
 
-version 1.101230
+version 1.101270
 
 =head1 SYNOPSIS
 
